@@ -1,37 +1,58 @@
-import arrow
+# type: ignore
 from typing import List
 
+import arrow
+
 from cached_property import cached_property
 
 from canvas_workflow_kit import events
+from canvas_workflow_kit.builtin_cqms.helper_population import Population
 from canvas_workflow_kit.protocol import (
-    ClinicalQualityMeasure,
-    ProtocolResult,
-    STATUS_DUE,
-    STATUS_SATISFIED,
-    STATUS_NOT_APPLICABLE,
     CONTEXT_GUIDANCE,
+    STATUS_DUE,
+    STATUS_NOT_APPLICABLE,
+    STATUS_SATISFIED,
+    ClinicalQualityMeasure,
+    ProtocolResult
 )
 from canvas_workflow_kit.recommendation import (
     InstructionRecommendation,
     InterviewRecommendation,
-    PrescribeRecommendation,
+    PrescribeRecommendation
 )
 from canvas_workflow_kit.timeframe import Timeframe
-from canvas_workflow_kit.builtin_cqms.helper_population import Population
-
 # flake8: noqa
 from canvas_workflow_kit.value_set.v2018 import (
-    AnnualWellnessVisit, Ethnicity, FaceToFaceInteraction, HealthAndBehavioralAssessmentInitial,
-    HealthAndBehavioralAssessmentReassessment, HealthBehavioralAssessmentIndividual,
-    HomeHealthcareServices, LimitedLifeExpectancy, OccupationalTherapyEvaluation, OfficeVisit,
-    OncAdministrativeSex, OphthalmologicalServices, Payer,
-    PreventiveCareServicesEstablishedOfficeVisit18AndUp, PreventiveCareServicesGroupCounseling,
-    PreventiveCareServicesIndividualCounseling, PreventiveCareServicesInitialOfficeVisit18AndUp,
-    PreventiveCareServicesOther, PsychVisitDiagnosticEvaluation, PsychVisitPsychotherapy,
-    Psychoanalysis, Race, SpeechAndHearingEvaluation, TobaccoNonUser,
-    TobaccoUseCessationCounseling, TobaccoUseCessationPharmacotherapy, TobaccoUseScreening,
-    TobaccoUser, MedicalReason)
+    AnnualWellnessVisit,
+    Ethnicity,
+    FaceToFaceInteraction,
+    HealthAndBehavioralAssessmentInitial,
+    HealthAndBehavioralAssessmentReassessment,
+    HealthBehavioralAssessmentIndividual,
+    HomeHealthcareServices,
+    LimitedLifeExpectancy,
+    MedicalReason,
+    OccupationalTherapyEvaluation,
+    OfficeVisit,
+    OncAdministrativeSex,
+    OphthalmologicalServices,
+    Payer,
+    PreventiveCareServicesEstablishedOfficeVisit18AndUp,
+    PreventiveCareServicesGroupCounseling,
+    PreventiveCareServicesIndividualCounseling,
+    PreventiveCareServicesInitialOfficeVisit18AndUp,
+    PreventiveCareServicesOther,
+    Psychoanalysis,
+    PsychVisitDiagnosticEvaluation,
+    PsychVisitPsychotherapy,
+    Race,
+    SpeechAndHearingEvaluation,
+    TobaccoNonUser,
+    TobaccoUseCessationCounseling,
+    TobaccoUseCessationPharmacotherapy,
+    TobaccoUser,
+    TobaccoUseScreening
+)
 
 
 class ClinicalQualityMeasure138v6(ClinicalQualityMeasure):
@@ -112,44 +133,45 @@ class ClinicalQualityMeasure138v6(ClinicalQualityMeasure):
     More information: https://ecqi.healthit.gov/ecqm/measures/cms138v6
     """
 
-    title = 'Preventive Care and Screening: Tobacco Use: Screening and Cessation Intervention'
+    class Meta:
+        title = 'Preventive Care and Screening: Tobacco Use: Screening and Cessation Intervention'
+        version = '2019-04-03v1'
+        default_display_interval_in_days = 365 * 2
 
-    default_display_interval_in_days = 365 * 2
+        description = (
+            'Patients aged 18 years and older who have not been screened for tobacco use OR '
+            'who have not received tobacco cessation intervention if identified as a tobacco user.'
+        )
+        information = 'https://ecqi.healthit.gov/ecqm/measures/cms138v6'
 
-    description = (
-        'Patients aged 18 years and older who have not been screened for tobacco use OR '
-        'who have not received tobacco cessation intervention if identified as a tobacco user.')
-    information = 'https://ecqi.healthit.gov/ecqm/measures/cms138v6'
+        identifiers = ['CMS138v6']
 
-    identifiers = ['CMS138v6']
+        types = ['CQM']
 
-    types = ['CQM']
-
-    responds_to_event_types = [
-        events.HEALTH_MAINTENANCE,
-    ]
-
-    authors = [
-        'American Medical Association (AMA)',
-        'PCPI(R) Foundation (PCPI[R])',
-    ]
-
-    @property
-    def references(self) -> List[str]:
-        return [
-            'Siu AL; U.S. Preventive Services Task Force. Behavioral and Pharmacotherapy Interventions for Tobacco Smoking Cessation in Adults, Including Pregnant Women: U.S. Preventive Services Task Force Recommendation Statement. Ann Intern Med. 2015 Oct 20;163(8):622-34.',
+        responds_to_event_types = [
+            events.HEALTH_MAINTENANCE,
         ]
 
-    funding_source = ''
+        authors = [
+            'American Medical Association (AMA)',
+            'PCPI(R) Foundation (PCPI[R])',
+        ]
+
+        references = [
+            'Siu AL; U.S. Preventive Services Task Force. Behavioral and Pharmacotherapy Interventions for Tobacco Smoking Cessation in Adults, Including Pregnant Women: U.S. Preventive Services Task Force Recommendation Statement. Ann Intern Med. 2015 Oct 20;163(8):622-34.',
+        ]
+        compute_on_change_types = [
+            ClinicalQualityMeasure.CHANGE_PROTOCOL_OVERRIDE,
+            ClinicalQualityMeasure.CHANGE_BILLING_LINE_ITEM,
+            ClinicalQualityMeasure.CHANGE_INSTRUCTION,
+            ClinicalQualityMeasure.CHANGE_INTERVIEW,
+            ClinicalQualityMeasure.CHANGE_MEDICATION,
+            ClinicalQualityMeasure.CHANGE_PATIENT,
+        ]
+
+        show_in_chart = False
+        show_in_population = False
 
-    compute_on_change_types = [
-        ClinicalQualityMeasure.CHANGE_PROTOCOL_OVERRIDE,
-        ClinicalQualityMeasure.CHANGE_BILLING_LINE_ITEM,
-        ClinicalQualityMeasure.CHANGE_INSTRUCTION,
-        ClinicalQualityMeasure.CHANGE_INTERVIEW,
-        ClinicalQualityMeasure.CHANGE_MEDICATION,
-        ClinicalQualityMeasure.CHANGE_PATIENT,
-    ]
     MINIMUM_AGE = 18
     POPULATION_1 = 'population 1'
     POPULATION_2 = 'population 2'
@@ -161,10 +183,6 @@ class ClinicalQualityMeasure138v6(ClinicalQualityMeasure):
         POPULATION_3: Population(),
     }
 
-    @classmethod
-    def revision(cls) -> str:
-        return '2019-04-03v1'
-
     @cached_property
     def tobacco_cessation_intervention_counseling(self) -> arrow:
         if not self.tobacco_use_screening_user:
