@@ -1,7 +1,5 @@
 from typing import Dict, List
 
-from cached_property import cached_property
-
 from canvas_workflow_kit import events
 from canvas_workflow_kit.canvas_code_set import CanvasCodeSet
 from canvas_workflow_kit.intervention import Intervention
@@ -25,27 +23,29 @@ from canvas_workflow_kit.value_set.v2018 import (
 
 
 class HyperlinkRecommendation(ClinicalQualityMeasure):
-    title = 'Hyperlink Recommendation'
-    version = "1.2"
-    changelog = "Initial release"
 
-    description = 'All patients with COVID Questionnaire completed Date < 7 days ago and >  5 days ago.'
-    information = 'https://canvas-medical.zendesk.com/hc/en-us/articles/360059084173-COVID-19-Risk-Assessment-Follow-Up-Protocol'
+    class Meta:
+        title = 'Hyperlink Recommendation'
+        version = "1.2"
+        changelog = "Initial release"
 
-    identifiers = ['CCP001v1']
+        description = 'All patients with COVID Questionnaire completed Date < 7 days ago and >  5 days ago.'
+        information = 'https://canvas-medical.zendesk.com/hc/en-us/articles/360059084173-COVID-19-Risk-Assessment-Follow-Up-Protocol'
 
-    types = ['CCP']
+        identifiers = ['CCP001v1']
 
-    responds_to_event_types = [
-        events.HEALTH_MAINTENANCE,
-    ]
-    authors = [
-        'Canvas Medical Team',
-    ]
+        types = ['CCP']
 
-    compute_on_change_types = [
-        ClinicalQualityMeasure.CHANGE_INTERVIEW,
-    ]
+        responds_to_event_types = [
+            events.HEALTH_MAINTENANCE,
+        ]
+        authors = [
+            'Canvas Medical Team',
+        ]
+
+        compute_on_change_types = [
+            ClinicalQualityMeasure.CHANGE_INTERVIEW,
+        ]
 
     def compute_results(self) -> ProtocolResult:
         result = ProtocolResult()
